@@ -1,4 +1,4 @@
-#! /usr/bin/env python
+#!/usr/local/bin/python2.6
 
 from __future__ import nested_scopes
 
@@ -122,9 +122,10 @@ class Database(DatabaseInterface):
         parentID = article.parentID
         if parentID is not None and self.articleIndex.has_key(parentID):
             parent = self.getArticle(archive, parentID)
-            myThreadKey = parent.threadKey + article.date + '-'
+            myThreadKey = (parent.threadKey + article.date + '.'
+                           + str(article.sequence) + '-')
         else:
-            myThreadKey = article.date + '-'
+            myThreadKey = article.date + '.' + str(article.sequence) + '-'
         article.threadKey = myThreadKey
         key = myThreadKey, article.msgid
         self.setThreadKey(archive, key, article.msgid)
@@ -224,12 +225,7 @@ class Article:
                 self.headers[i] = message[i]
 
         # Read the message body
-        # Check Scrubber-munged paylaod
-        if message.get('x-mailman-scrubbed'):
-            decode = False
-        else:
-            decode = True
-        s = StringIO(message.get_payload(decode=decode)\
+        s = StringIO(message.get_payload(decode=True)\
                      or message.as_string().split('\n\n',1)[1])
         self.body = s.readlines()
 
@@ -423,7 +419,8 @@ class T:
                 else:
                     parent = self.database.getArticle(self.archive,
                                                     article.parentID)
-                    article.threadKey = parent.threadKey+article.date+'-'
+                    article.threadKey = (parent.threadKey + article.date + '.'
+                                         + str(article.sequence) + '-')
                 self.database.setThreadKey(self.archive,
                     (article.threadKey, article.msgid),
                     msgid)
@@ -637,9 +634,11 @@ class T:
             article.parentID = parentID = self.get_parent_info(arch, article)
             if parentID:
                 parent = self.database.getArticle(arch, parentID)
-                article.threadKey = parent.threadKey + article.date + '-'
+                article.threadKey = (parent.threadKey + article.date + '.'
+                                     + str(article.sequence) + '-')
             else:
-                article.threadKey = article.date + '-'
+                article.threadKey = (article.date + '.'
+                                     + str(article.sequence) + '-')
             key = article.threadKey, article.msgid
 
             self.database.setThreadKey(arch, key, article.msgid)
@@ -652,8 +651,10 @@ class T:
     def get_parent_info(self, archive, article):
         parentID = None
         if article.in_reply_to:
-            parentID = article.in_reply_to
-        elif article.references:
+            if self.database.hasArticle(archive, article.in_reply_to):
+                # Only use In-Reply-To if it's in the archive.
+                parentID = article.in_reply_to
+        if not parentID and article.references:
             refs = self._remove_external_references(article.references)
             if refs:
                 maxdate = self.database.getArticle(archive, refs[0])
@@ -662,11 +663,15 @@ class T:
                     if a.date > maxdate.date:
                         maxdate = a
                 parentID = maxdate.msgid
-        else:
+        if not parentID:
             # Get the oldest article with a matching subject, and
             # assume this is a follow-up to that article
-            parentID = self.database.getOldestArticle(archive,
-                                                      article.subject)
+            # But, use the subject that's in the database
+            if article.decoded.has_key('stripped'):
+                subject = article.decoded['stripped'].lower()
+            else:
+                subject = article.subject.lower()
+            parentID = self.database.getOldestArticle(archive, subject)
 
         if parentID and not self.database.hasArticle(archive, parentID):
             parentID = None
