@@ -1,6 +1,6 @@
 # -*- python -*-
 
-# Copyright (C) 1998-2008 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2010 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -396,6 +396,29 @@ MTA = 'Manual'
 # for details.
 POSTFIX_STYLE_VIRTUAL_DOMAINS = []
 
+# If you specify any virtual domains in the above list, Mailman will generate
+# a virtual-mailman file containing virtual mappings of the form
+#
+# listaddress@dom2.ain   listaddress
+# etc.
+#
+# to map the list addresses in those domains to local addresses. If you need
+# mappings that specify a domain on the right hand side such as
+#
+# listaddress@dom2.ain   listaddress@localhost
+# or
+# listaddress@dom2.ain   listaddress@other.local.domain
+#
+# specify the desired local domain in mm_cfg.py as for example
+#
+# VIRTUAL_MAILMAN_LOCAL_DOMAIN = 'localhost'
+# or
+# VIRTUAL_MAILMAN_LOCAL_DOMAIN = 'other.local.domain'
+#
+# Whatever string value you set will be literally appended with an '@' to the
+# listaddress local parts on the right hand side.
+VIRTUAL_MAILMAN_LOCAL_DOMAIN = None
+
 # These variables describe the program to use for regenerating the aliases.db
 # and virtual-mailman.db files, respectively, from the associated plain text
 # files.  The file being updated will be appended to this string (with a
@@ -678,8 +701,11 @@ VERP_CONFIRM_FORMAT = '%(addr)s+%(cookie)s'
 # From: local_part@host
 # into
 # To: "local_part" <local_part@host>
-# when replying, so we skip everything up to '<' if any.
-VERP_CONFIRM_REGEXP = r'^(.*<)?(?P<addr>[^+]+?)\+(?P<cookie>[^@]+)@.*$'
+# or even
+# To: "local_part@host" <local_part@host>
+# and may even fold the header when replying, so we skip everything up to '<'
+# if any and include ($s) so dot will match the newline in a folded header.
+VERP_CONFIRM_REGEXP = r'(?s)^(.*<)?(?P<addr>.+)\+(?P<cookie>[^@+]+)@.*$'
 
 # Set this to Yes to enable VERP-like (more user friendly) confirmations
 VERP_CONFIRMATIONS = No
@@ -1029,6 +1055,14 @@ DEFAULT_OBSCURE_ADDRESSES = Yes
 # lists with no archives).
 ALLOW_RFC2369_OVERRIDES = Yes
 
+# RFC 2822 suggests that not adding a Sender header when Mailman is the agent
+# responsible for the actual transmission is a breach of the RFC.  However,
+# some MUAs (notably Outlook) tend to display the Sender header instead of the
+# From details, confusing users and actually losing the original sender when
+# forwarding mail.  By setting this variable to Yes, list owners will be
+# given the option to avoid setting this header.
+ALLOW_SENDER_OVERRIDES = Yes
+
 # Defaults for content filtering on mailing lists.  DEFAULT_FILTER_CONTENT is
 # a flag which if set to true, turns on content filtering.
 DEFAULT_FILTER_CONTENT = No
@@ -1100,7 +1134,7 @@ MIME_DIGEST_KEEP_HEADERS = [
     'Date', 'From', 'To', 'Cc', 'Subject', 'Message-ID', 'Keywords',
     # I believe we should also keep these headers though.
     'In-Reply-To', 'References', 'Content-Type', 'MIME-Version',
-    'Content-Transfer-Encoding', 'Precedence', 'Reply-To',
+    'Content-Transfer-Encoding', 'Precedence', 'Reply-To', 'List-Post',
     # Mailman 2.0 adds these headers
     'Message',
     ]
@@ -1243,7 +1277,7 @@ PENDINGDB_LOCK_DEBUGGING = Off
 # These directories are used to find various important files in the Mailman
 # installation.  PREFIX and EXEC_PREFIX are set by configure and should point
 # to the installation directory of the Mailman package.
-PYTHON          = '/usr/local/bin/python2.5'
+PYTHON          = '/usr/local/bin/python2.6'
 PREFIX          = '/usr/local/lib/mailman'
 EXEC_PREFIX     = '${prefix}'
 VAR_PREFIX      = '/var/spool/mailman'
@@ -1257,7 +1291,7 @@ CGIEXT = ''
 
 # Group id that group-owns the Mailman installation
 MAILMAN_USER = '_mailman'
-MAILMAN_GROUP = ''
+MAILMAN_GROUP = '_mailman'
 
 # Enumeration for Mailman cgi widget types
 Toggle      = 1
@@ -1389,6 +1423,7 @@ def add_language(code, description, charset, direction='ltr'):
     LC_DESCRIPTIONS[code] = (description, charset, direction)
 
 add_language('ar',    _('Arabic'),              'utf-8',       'rtl')
+add_language('ast',   _('Asturian'),            'iso-8859-1',  'ltr')
 add_language('ca',    _('Catalan'),             'utf-8',       'ltr')
 add_language('cs',    _('Czech'),               'iso-8859-2',  'ltr')
 add_language('da',    _('Danish'),              'iso-8859-1',  'ltr')
